@@ -637,7 +637,7 @@ int ssl_hook_Access(request_rec *r)
     int i;
     BOOL renegotiate;
     BOOL renegotiate_quick;
-#ifdef SSL_EXPERIMENTAL
+#ifdef SSL_EXPERIMENTAL_PERDIRCA
     BOOL reconfigured_locations;
     STACK_OF(X509_NAME) *skCAList;
     char *cpCAPath;
@@ -704,7 +704,7 @@ int ssl_hook_Access(request_rec *r)
      */
     renegotiate            = FALSE;
     renegotiate_quick      = FALSE;
-#ifdef SSL_EXPERIMENTAL
+#ifdef SSL_EXPERIMENTAL_PERDIRCA
     reconfigured_locations = FALSE;
 #endif
 
@@ -870,7 +870,7 @@ int ssl_hook_Access(request_rec *r)
      *  OpenSSL provides a SSL_load_verify_locations() function we've no other
      *  chance to provide this functionality...
      */
-#ifdef SSL_EXPERIMENTAL
+#ifdef SSL_EXPERIMENTAL_PERDIRCA
     if (   (   dc->szCACertificateFile != NULL
             && (   sc->szCACertificateFile == NULL
                 || (   sc->szCACertificateFile != NULL
@@ -907,7 +907,7 @@ int ssl_hook_Access(request_rec *r)
         ssl_log(r->server, SSL_LOG_TRACE,
                 "Changed client verification locations will force renegotiation");
     }
-#endif /* SSL_EXPERIMENTAL */
+#endif /* SSL_EXPERIMENTAL_PERDIRCA */
 
 #ifdef SSL_CONSERVATIVE 
     /* 
@@ -1028,7 +1028,7 @@ int ssl_hook_Access(request_rec *r)
      * to the old values. This should be changed with forthcoming OpenSSL
      * versions when better functionality is avaiable.
      */
-#ifdef SSL_EXPERIMENTAL
+#ifdef SSL_EXPERIMENTAL_PERDIRCA
     if (renegotiate && reconfigured_locations) {
         if (!SSL_CTX_load_verify_locations(ctx,
                 sc->szCACertificateFile, sc->szCACertificatePath)) {
@@ -1038,7 +1038,7 @@ int ssl_hook_Access(request_rec *r)
             return FORBIDDEN;
         }
     }
-#endif /* SSL_EXPERIMENTAL */
+#endif /* SSL_EXPERIMENTAL_PERDIRCA */
 
     /*
      * Check SSLRequire boolean expressions
